@@ -473,14 +473,6 @@ class BaseCameraConfig(TypedDict):
     name: str
     nativeId: Optional[str]
     isCloud: Optional[bool]
-    hasLight: Optional[bool]
-    hasSiren: Optional[bool]
-    hasBinarySensor: Optional[bool]
-    hasMotionDetection: Optional[bool]
-    hasObjectDetection: Optional[bool]
-    hasAudioDetection: Optional[bool]
-    hasPtz: Optional[bool]
-    hasBattery: Optional[bool]
     disabled: Optional[bool]
     info: Optional[CameraInformation]
 
@@ -493,61 +485,6 @@ class PartialCameraConfig(BaseCameraConfig, total=False):
     sources: NotRequired[list[CameraConfigInputSettings]]
 
 
-class CameraDelegate(Protocol):
-    async def snapshot(self, source_id: str, force_new: Optional[bool] = None) -> Optional[bytes]: ...
-    async def streamUrl(self, source_name: str) -> str: ...
-
-
-class PTZSpeed(TypedDict):
-    pan: NotRequired[float]
-    tilt: NotRequired[float]
-    zoom: NotRequired[float]
-
-
-class PTZBaseCommand(TypedDict):
-    speed: NotRequired[PTZSpeed]
-
-
-class PTZStopCommand(PTZBaseCommand):
-    type: Literal["stop"]
-
-
-class PTZHomeCommand(PTZBaseCommand):
-    type: Literal["home"]
-
-
-class PTZPresetCommand(PTZBaseCommand):
-    type: Literal["preset"]
-    preset: str
-
-
-class PTZMoveCommand(PTZBaseCommand):
-    type: Literal["absolute", "relative"]
-    pan: NotRequired[float]
-    tilt: NotRequired[float]
-    zoom: NotRequired[float]
-
-
-class PTZContinuousMoveCommand(PTZBaseCommand):
-    type: Literal["continuous"]
-    pan: NotRequired[float]
-    tilt: NotRequired[float]
-    zoom: NotRequired[float]
-    timeout: NotRequired[float]
-
-
-PTZCommand = Union[PTZHomeCommand, PTZPresetCommand, PTZMoveCommand, PTZContinuousMoveCommand]
-
-
-class CameraPTZDelegate(Protocol):
-    async def ptzCommand(self, command: PTZCommand) -> None: ...
-
-
-class CameraDelegates(TypedDict):
-    cameraDelegate: CameraDelegate
-    ptzDelegate: CameraPTZDelegate
-
-
 class RTSPUrlOptions(TypedDict, total=False):
     video: bool
     audio: Union[bool, RTSPAudioCodec, list[RTSPAudioCodec]]
@@ -642,14 +579,6 @@ class Camera(TypedDict):
     name: str
     disabled: bool
     isCloud: bool
-    hasLight: bool
-    hasSiren: bool
-    hasBinarySensor: bool
-    hasMotionDetection: bool
-    hasObjectDetection: bool
-    hasAudioDetection: bool
-    hasPtz: bool
-    hasBattery: bool
     info: CameraInformation
     type: CameraType
     snapshotTTL: int
@@ -662,6 +591,86 @@ class Camera(TypedDict):
     sources: list[CameraInput]
 
 
+class CameraDeviceCapability(str, Enum):
+    MotionSensor = "MotionSensor"
+    MotionDetector = "MotionDetector"
+
+    AudioSensor = "AudioSensor"
+
+    ObjectSensor = "ObjectSensor"
+    ObjectDetector = "ObjectDetector"
+
+    Light = "Light"
+    Siren = "Siren"
+    Doorbell = "Doorbell"
+
+    Battery = "Battery"
+
+    PTZ = "PTZ"
+    PTZMove = "PTZMove"
+    PTZHome = "PTZHome"
+    PTZPresets = "PTZPresets"
+    PTZZoom = "PTZZoom"
+
+    Snapshot = "Snapshot"
+    StreamUrl = "StreamUrl"
+
+    Reboot = "Reboot"
+
+
+class PTZSpeed(TypedDict):
+    pan: NotRequired[float]
+    tilt: NotRequired[float]
+    zoom: NotRequired[float]
+
+
+class PTZBaseCommand(TypedDict):
+    speed: NotRequired[PTZSpeed]
+
+
+class PTZStopCommand(PTZBaseCommand):
+    type: Literal["stop"]
+
+
+class PTZHomeCommand(PTZBaseCommand):
+    type: Literal["home"]
+
+
+class PTZPresetCommand(PTZBaseCommand):
+    type: Literal["preset"]
+    preset: str
+
+
+class PTZMoveCommand(PTZBaseCommand):
+    type: Literal["absolute", "relative"]
+    pan: NotRequired[float]
+    tilt: NotRequired[float]
+    zoom: NotRequired[float]
+
+
+class PTZContinuousMoveCommand(PTZBaseCommand):
+    type: Literal["continuous"]
+    pan: NotRequired[float]
+    tilt: NotRequired[float]
+    zoom: NotRequired[float]
+    timeout: NotRequired[float]
+
+
+PTZCommand = Union[PTZHomeCommand, PTZPresetCommand, PTZMoveCommand, PTZContinuousMoveCommand]
+
+
+class PTZInterface(Protocol):
+    async def ptzCommand(self, command: PTZCommand) -> None: ...
+
+
+class SnapshotInterface(Protocol):
+    async def snapshot(self, source_id: str, force_new: Optional[bool] = None) -> Optional[bytes]: ...
+
+
+class StreamingInterface(Protocol):
+    async def streamUrl(self, source_name: str) -> str: ...
+
+
 StateValue = Union[
     LightState,
     MotionState,
@@ -686,6 +695,11 @@ class CameraPropertyObservableObject(TypedDict):
     new_state: Any
 
 
+class CameraCapabilitiesObservableObject(TypedDict):
+    old_capabilities: list[CameraDeviceCapability]
+    new_capabilities: list[CameraDeviceCapability]
+
+
 class CameraConfigInputSettingsPartial(TypedDict, total=False):
     # _id: str
     name: str
@@ -724,7 +738,7 @@ class CameraDevice(Protocol):
     @property
     def has_siren(self) -> bool: ...
     @property
-    def has_binary_sensor(self) -> bool: ...
+    def has_doorbell(self) -> bool: ...
     @property
     def has_battery(self) -> bool: ...
     @property
@@ -741,6 +755,9 @@ class CameraDevice(Protocol):
     def detection_settings(self) -> CameraDetectionSettings: ...
     @property
     def frameworker_settings(self) -> CameraFrameWorkerSettings: ...
+
+    @property
+    def sources(self) -> list[CameraDeviceSource]: ...
     @property
     def stream_source(self) -> CameraDeviceSource: ...
     @property
@@ -751,15 +768,10 @@ class CameraDevice(Protocol):
     def low_resolution_source(self) -> Optional[CameraDeviceSource]: ...
     @property
     def snapshot_source(self) -> Optional[CameraSource]: ...
-    @property
-    def ptz(self) -> CameraPTZDelegate: ...
-    @property
-    def delegate(self) -> CameraDelegate: ...
-    @property
-    def sources(self) -> list[CameraDeviceSource]: ...
 
     on_connected: HybridObservable[bool]
     on_frameworker_connected: HybridObservable[bool]
+
     on_light_switched: HybridObservable[LightState]
     on_motion_detected: HybridObservable[MotionState]
     on_audio_detected: HybridObservable[AudioState]
@@ -804,6 +816,8 @@ class CameraDevice(Protocol):
         self, property: Union[CameraPublicProperties, list[CameraPublicProperties]]
     ) -> HybridObservable[CameraPropertyObservableObject]: ...
 
+    def on_capabilities_change(self) -> HybridObservable[CameraCapabilitiesObservableObject]: ...
+
     @overload
     def get_value(self, state_name: Literal["light"]) -> LightState: ...
     @overload
@@ -830,10 +844,7 @@ class CameraDevice(Protocol):
         BatteryState,
     ]: ...
 
-    @overload
-    def set_delegate(self, name: Literal["cameraDelegate"], delegate: CameraDelegate) -> None: ...
-    @overload
-    def set_delegate(self, name: Literal["ptzDelegate"], delegate: CameraPTZDelegate) -> None: ...
+    def extend(self, interfaces: Union[PTZInterface, SnapshotInterface, StreamingInterface]) -> None: ...
 
     async def connect(self) -> None: ...
     async def disconnect(self) -> None: ...
@@ -891,6 +902,10 @@ class CameraDevice(Protocol):
         event_data: BatterySetEvent,
     ) -> None: ...
 
+    def get_capabilities(self) -> list[CameraDeviceCapability]: ...
+    def has_capability(self, capability: CameraDeviceCapability) -> bool: ...
+    async def add_capabilities(self, capabilities: list[CameraDeviceCapability]) -> None: ...
+
 
 CameraSelectedCallback = Union[
     Callable[[CameraDevice, CameraExtension], None],
@@ -931,7 +946,7 @@ class DeviceManager(Protocol):
 
 @runtime_checkable
 class CoreManager(Protocol):
-    async def connect_to_plugin(self, plugin_name: str) -> "Optional[PluginInterface]": ...
+    async def connect_to_plugin(self, plugin_name: str) -> "Optional[CuiPlugin]": ...
     async def get_ffmpeg_path(self) -> str: ...
     async def get_hwaccel_info(self, options: "HWAccelOptions") -> "list[FfmpegArgs]": ...
     async def get_server_addresses(self) -> list[str]: ...
@@ -1238,70 +1253,37 @@ class AudioDetectionPluginResponse(TypedDict):
     detected: bool
 
 
-class CuiCapability(str, Enum):
+class CuiPluginCapability(str, Enum):
     MotionDetector = "MotionDetector"
     ObjectDetector = "ObjectDetector"
     AudioDetector = "AudioDetector"
-    PTZMove = "PTZMove"
-    PTZHome = "PTZHome"
-    PTZPresets = "PTZPresets"
-    PTZZoom = "PTZZoom"
 
 
-class BasePlugin(metaclass=ABCMeta):
+class CuiPlugin(metaclass=ABCMeta):
     @abstractmethod
     def __init__(self, logger: "LoggerService", api: "PluginAPI") -> None: ...
     @abstractmethod
     async def configureCameras(self, cameras: list[CameraDevice]) -> None: ...
     @abstractmethod
-    async def getCapabilities(self) -> list[CuiCapability]: ...
+    async def getCapabilities(self) -> list[CuiPluginCapability]: ...
 
+    async def interfaceSchema(self) -> Optional[list[JsonSchema]]:
+        return None
 
-class MotionDetectionPlugin(BasePlugin):
-    @abstractmethod
-    async def interfaceSchema(self) -> Optional[list[JsonSchema]]: ...
-    @abstractmethod
-    async def detectMotion(
-        self, video_data: bytes, config: dict[str, Any]
-    ) -> MotionDetectionPluginResponse: ...
-
-
-class ObjectDetectionPlugin(BasePlugin):
-    @abstractmethod
-    async def interfaceSchema(self) -> Optional[list[JsonSchema]]: ...
-    @abstractmethod
-    async def detectObjects(
-        self, image_data: bytes, metadata: ImageMetadata, config: dict[str, Any]
-    ) -> ObjectDetectionPluginResponse: ...
-
-
-class AudioDetectionPlugin(BasePlugin):
-    @abstractmethod
-    async def interfaceSchema(self) -> Optional[list[JsonSchema]]: ...
-    @abstractmethod
     async def detectAudio(
         self, audio_data: bytes, metadata: AudioMetadata, config: dict[str, Any]
-    ) -> AudioDetectionPluginResponse: ...
+    ) -> Optional[AudioDetectionPluginResponse]:
+        return None
 
-
-class PtzPlugin(BasePlugin):
-    pass
-
-
-@runtime_checkable
-class PluginInterface(Protocol):
-    async def configureCameras(self, camera_devices: list[CameraDevice]) -> None: ...
-    async def getCapabilities(self) -> list[CuiCapability]: ...
-    async def interfaceSchema(self) -> Optional[list[JsonSchema]]: ...
     async def detectMotion(
         self, video_data: bytes, config: dict[str, Any]
-    ) -> MotionDetectionPluginResponse: ...
+    ) -> Optional[MotionDetectionPluginResponse]:
+        return None
+
     async def detectObjects(
         self, image_data: bytes, metadata: ImageMetadata, config: dict[str, Any]
-    ) -> ObjectDetectionPluginResponse: ...
-    async def detectAudio(
-        self, audio_data: bytes, metadata: AudioMetadata, config: dict[str, Any]
-    ) -> AudioDetectionPluginResponse: ...
+    ) -> Optional[ObjectDetectionPluginResponse]:
+        return None
 
 
 @runtime_checkable
